==> haskell-mustache-2.4.1-97-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mustache
version:              2.4.1
visibility:           public
id:                   mustache-2.4.1-272n0kQgEFPDTU1voOWBNk
key:                  mustache-2.4.1-272n0kQgEFPDTU1voOWBNk
license:              BSD-3-Clause
copyright:            (c) 2015 - 2022 Justus Adam
maintainer:           dev@justus.science
author:               Justus Adam
homepage:             https://github.com/JustusAdam/mustache
synopsis:             A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.

    Implements the mustache spec version 1.1.3.

    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.

category:             Development
abi:                  2061d39182b756c6f4490df2a1d8390f
exposed:              True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types

hidden-modules:
    Text.Mustache.Internal Text.Mustache.Internal.Types Paths_mustache

import-dirs:          /usr/lib/ghc-9.0.2/site-local/mustache-2.4.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/mustache-2.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mustache
hs-libraries:         HSmustache-2.4.1-272n0kQgEFPDTU1voOWBNk
depends:
    aeson-2.1.1.0-6f0SUJ6dh2u49Oyg8vjVqb base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.2
    filepath-1.4.2.1 mtl-2.2.2 parsec-3.1.14.0
    scientific-0.3.7.0-994Cd8S1bkZ9FDNHRggxUL template-haskell-2.17.0.0
    text-1.2.5.0 th-lift-0.8.2-47INKJD6iIF1IlUc8HcOrC
    unordered-containers-0.2.19.1-8VYAOBvAPnuAGZDvxcTgvW
    vector-0.13.0.0-C4IY0qsV06C5Tx1gtETdzw

haddock-interfaces:   /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html:         /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mustache-2.4.1-98-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mustache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mustache
version:              2.4.1
visibility:           public
id:                   mustache-2.4.1-In3HtfbPsqZHJtfBQLjay2
key:                  mustache-2.4.1-In3HtfbPsqZHJtfBQLjay2
license:              BSD-3-Clause
copyright:            (c) 2015 - 2022 Justus Adam
maintainer:           dev@justus.science
author:               Justus Adam
homepage:             https://github.com/JustusAdam/mustache
synopsis:             A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.

    Implements the mustache spec version 1.1.3.

    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.

category:             Development
abi:                  a418b8bc09968caeaf188e32cfadc323
exposed:              True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types

hidden-modules:
    Text.Mustache.Internal Text.Mustache.Internal.Types Paths_mustache

import-dirs:          /usr/lib/ghc-9.0.2/site-local/mustache-2.4.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/mustache-2.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mustache
hs-libraries:         HSmustache-2.4.1-In3HtfbPsqZHJtfBQLjay2
depends:
    aeson-2.1.1.0-4M4Q1RS88i145fLgkhDJeF base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.2
    filepath-1.4.2.1 mtl-2.2.2 parsec-3.1.14.0
    scientific-0.3.7.0-994Cd8S1bkZ9FDNHRggxUL template-haskell-2.17.0.0
    text-1.2.5.0 th-lift-0.8.2-47INKJD6iIF1IlUc8HcOrC
    unordered-containers-0.2.19.1-1oz2vTo8QZe9pPW8EMafVJ
    vector-0.13.0.0-C4IY0qsV06C5Tx1gtETdzw

haddock-interfaces:   /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html:         /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
